package com.ruoyi.business.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TbUserBidStoreMapper;
import com.ruoyi.business.domain.TbUserBidStore;
import com.ruoyi.business.service.ITbUserBidStoreService;
import com.ruoyi.common.core.text.Convert;

/**
 * 我收藏的项目Service业务层处理
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Service
public class TbUserBidStoreServiceImpl implements ITbUserBidStoreService 
{
    @Autowired
    private TbUserBidStoreMapper tbUserBidStoreMapper;

    /**
     * 查询我收藏的项目
     * 
     * @param userBidId 我收藏的项目主键
     * @return 我收藏的项目
     */
    @Override
    public TbUserBidStore selectTbUserBidStoreByUserBidId(Long userBidId)
    {
        return tbUserBidStoreMapper.selectTbUserBidStoreByUserBidId(userBidId);
    }

    /**
     * 查询我收藏的项目列表
     * 
     * @param tbUserBidStore 我收藏的项目
     * @return 我收藏的项目
     */
    @Override
    public List<TbUserBidStore> selectTbUserBidStoreList(TbUserBidStore tbUserBidStore)
    {
        return tbUserBidStoreMapper.selectTbUserBidStoreList(tbUserBidStore);
    }

    /**
     * 新增我收藏的项目
     * 
     * @param tbUserBidStore 我收藏的项目
     * @return 结果
     */
    @Override
    public int insertTbUserBidStore(TbUserBidStore tbUserBidStore)
    {
        tbUserBidStore.setCreateTime(DateUtils.getNowDate());
        return tbUserBidStoreMapper.insertTbUserBidStore(tbUserBidStore);
    }

    /**
     * 修改我收藏的项目
     * 
     * @param tbUserBidStore 我收藏的项目
     * @return 结果
     */
    @Override
    public int updateTbUserBidStore(TbUserBidStore tbUserBidStore)
    {
        return tbUserBidStoreMapper.updateTbUserBidStore(tbUserBidStore);
    }

    /**
     * 批量删除我收藏的项目
     * 
     * @param userBidIds 需要删除的我收藏的项目主键
     * @return 结果
     */
    @Override
    public int deleteTbUserBidStoreByUserBidIds(String userBidIds)
    {
        return tbUserBidStoreMapper.deleteTbUserBidStoreByUserBidIds(Convert.toStrArray(userBidIds));
    }

    /**
     * 删除我收藏的项目信息
     * 
     * @param userBidId 我收藏的项目主键
     * @return 结果
     */
    @Override
    public int deleteTbUserBidStoreByUserBidId(Long userBidId)
    {
        return tbUserBidStoreMapper.deleteTbUserBidStoreByUserBidId(userBidId);
    }
}
